@@ -289,13 +289,7 @@ liferea_browser_online_status_changed (NetworkMonitor *nm, gboolean online, gpoi
 static void
 liferea_browser_proxy_changed (NetworkMonitor *nm, gpointer userdata)
 {
-	liferea_webkit_set_proxy (
-		network_get_proxy_detect_mode (),
-		network_get_proxy_host (),
-		network_get_proxy_port (),
-		network_get_proxy_username (),
-		network_get_proxy_password ()
-	);
+	liferea_webkit_set_proxy (network_get_proxy_detect_mode ());
 }
 
 LifereaBrowser *
@@ -317,9 +311,11 @@ liferea_browser_new (gboolean forceInternalBrowsing)
 	                  G_CALLBACK (liferea_browser_proxy_changed),
 	                  browser);
 
-	debug0 (DEBUG_NET, "Setting initial HTML widget proxy...");
+	debug (DEBUG_NET, "Setting initial HTML widget proxy...");
 	liferea_browser_proxy_changed (network_monitor_get (), browser);
 
+	liferea_browser_update_stylesheet (browser);
+
 	return browser;
 }
 
@@ -416,7 +412,7 @@ liferea_browser_load_finished_cb (GObject *object, GAsyncResult *result, gpointe
 
 	js_result = webkit_web_view_run_javascript_finish (WEBKIT_WEB_VIEW (object), result, &error);
 	if (!js_result) {
-		debug1 (DEBUG_HTML, "Error running javascript: %s", error->message);
+		debug (DEBUG_HTML, "Error running javascript: %s", error->message);
 		g_error_free (error);
 		return;
 	}
@@ -427,7 +423,7 @@ liferea_browser_load_finished_cb (GObject *object, GAsyncResult *result, gpointe
 		gboolean result = jsc_value_to_boolean (value);
 
 		if (!result && browser->readerMode && browser->url) {
-			debug0 (DEBUG_HTML, "loadContent() reader mode fail -> reloading without reader");
+			debug (DEBUG_HTML, "loadContent() reader mode fail -> reloading without reader");
 			browser->readerMode = FALSE;
 			liferea_browser_launch_URL_internal (browser, browser->url);
 		}
@@ -446,24 +442,27 @@ liferea_browser_load_finished (LifereaBrowser *browser, const gchar *location)
 	    - for internal content: always (Readability is enable on demand here)
 	 */
 	if (browser->readerMode || (location == strstr (location, "liferea://"))) {
-		g_autoptr(GBytes) b1 = NULL, b2 = NULL, b3 = NULL;
+		g_autoptr(GBytes) b1, b2, b3, b4;
 
 		// Return Readability.js and Liferea specific loader code
 		b1 = g_resources_lookup_data ("/org/gnome/liferea/readability/Readability-readerable.js", 0, NULL);
 		b2 = g_resources_lookup_data ("/org/gnome/liferea/readability/Readability.js", 0, NULL);
-		b3 = g_resources_lookup_data ("/org/gnome/liferea/htmlview.js", 0, NULL);
+		b3 = g_resources_lookup_data ("/org/gnome/liferea/dompurify/purify.min.js", 0, NULL);
+		b4 = g_resources_lookup_data ("/org/gnome/liferea/htmlview.js", 0, NULL);
 
 		g_assert(b1 != NULL);
 		g_assert(b2 != NULL);
 		g_assert(b3 != NULL);
+		g_assert(b4 != NULL);
 
-		debug1 (DEBUG_GUI, "Enabling reader mode for '%s'", location);
+		debug (DEBUG_GUI, "Enabling reader mode for '%s'", location);
 		liferea_webkit_run_js (
 			browser->renderWidget,
-			g_strdup_printf ("%s\n%s\n%s\nloadContent(%s, '%s');\n",
+			g_strdup_printf ("%s\n%s\n%s\n%s\nloadContent(%s, '%s');\n",
 		        (gchar *)g_bytes_get_data (b1, NULL),
 			(gchar *)g_bytes_get_data (b2, NULL),
 			(gchar *)g_bytes_get_data (b3, NULL),
+			(gchar *)g_bytes_get_data (b4, NULL),
 			(browser->readerMode?"true":"false"),
 			browser->content != NULL ? browser->content : ""),
 			liferea_browser_load_finished_cb
@@ -497,7 +496,8 @@ liferea_browser_load_reader_content_cb (const struct updateResult * const result
 	}
 		
 	liferea_webkit_run_js (browser->renderWidget,
-	                       g_strdup_printf ("loadContent(true, '<body>%s</body>');\n",
+	                       g_strdup_printf ("setBase('%s');loadContent(true, '<body>%s</body>');\n",
+	                                        result->source,
 	                                        browser->content),
 	                       liferea_browser_load_finished_cb);
 }
@@ -546,7 +546,7 @@ liferea_browser_handle_URL (LifereaBrowser *browser, const gchar *url)
 
 	conf_get_bool_value (BROWSE_INSIDE_APPLICATION, &browse_inside_application);
 
-	debug2 (DEBUG_GUI, "handle URL: %s %s %s",
+	debug (DEBUG_GUI, "handle URL: %s %s",
 	        browse_inside_application?"true":"false",
 	        browser->forceInternalBrowsing?"true":"false");
 
@@ -690,7 +690,7 @@ liferea_browser_refresh (LifereaBrowser *browser, guint mode)
 			break;
 	}
 
-	if (debug_level & DEBUG_HTML) {
+	if (debug_get_flags () & DEBUG_HTML) {
 		gchar *filename = common_create_cache_filename (NULL, "output", "html");
 		g_file_set_contents (filename, content, -1, NULL);
 		g_free (filename);
